@@ -4,12 +4,16 @@ import sys
 import numpy as np
 import odtbrain
 
+import pytest
+
 from common_methods import create_test_sino_2d, cutout, \
     get_test_parameter_set, write_results, get_results
 
 WRITE_RES = False
 
 
+@pytest.mark.filterwarnings(
+    "ignore::odtbrain.warn.DataUndersampledWarning")
 def test_2d_integrate():
     myframe = sys._getframe()
     sino, angles = create_test_sino_2d()
